  function [granite] = initializeGranite(args)

  arguments
    args.type          char    {mustBeMember(args.type,{'rigid', 'flexible', 'none', 'modal-analysis', 'init'})} = 'flexible'
    args.Foffset       logical {mustBeNumericOrLogical} = false
    args.density (1,1) double {mustBeNumeric, mustBeNonnegative} = 2800 % Density [kg/m3]
    args.K  (3,1) double {mustBeNumeric, mustBeNonnegative} = [4e9; 3e8; 8e8] % [N/m]
    args.C  (3,1) double {mustBeNumeric, mustBeNonnegative} = [4.0e5; 1.1e5; 9.0e5] % [N/(m/s)]
    args.x0 (1,1) double {mustBeNumeric} = 0 % Rest position of the Joint in the X direction [m]
    args.y0 (1,1) double {mustBeNumeric} = 0 % Rest position of the Joint in the Y direction [m]
    args.z0 (1,1) double {mustBeNumeric} = 0 % Rest position of the Joint in the Z direction [m]
    args.sample_pos (1,1) double {mustBeNumeric} = 0.8 % Height of the measurment point [m]
  end

  granite = struct();

  switch args.type
    case 'none'
      granite.type = 0;
    case 'rigid'
      granite.type = 1;
    case 'flexible'
      granite.type = 2;
    case 'modal-analysis'
      granite.type = 3;
    case 'init'
      granite.type = 4;
  end

  granite.density = args.density; % [kg/m3]
  granite.STEP    = 'granite.STEP';

  granite.sample_pos = args.sample_pos; % [m]

  granite.K = args.K; % [N/m]
  granite.C = args.C; % [N/(m/s)]

  if args.Foffset && ~strcmp(args.type, 'none') && ~strcmp(args.type, 'rigid') && ~strcmp(args.type, 'init')
    load('Foffset.mat', 'Fgm');
    granite.Deq = -Fgm'./granite.K;
  else
    granite.Deq = zeros(6,1);
  end

if exist('./mat', 'dir')
    if exist('./mat/nass_stages.mat', 'file')
        save('mat/nass_stages.mat', 'granite', '-append');
    else
        save('mat/nass_stages.mat', 'granite');
    end
elseif exist('./matlab', 'dir')
    if exist('./matlab/mat/nass_stages.mat', 'file')
        save('matlab/mat/nass_stages.mat', 'granite', '-append');
    else
        save('matlab/mat/nass_stages.mat', 'granite');
    end
end
